@@ -2,16 +2,14 @@ use strict;
 use warnings;
 
 package Net::Amazon::Route53;
-{
-  $Net::Amazon::Route53::VERSION = '0.123250';
-}
+$Net::Amazon::Route53::VERSION = '0.160530';
 use LWP::UserAgent;
 use HTTP::Request;
 use Digest::HMAC_SHA1;
 use MIME::Base64;
 use XML::Bare;
 use HTML::Entities;
-use Mouse;
+use Any::Moose;
 
 use Net::Amazon::Route53::HostedZone;
 use Net::Amazon::Route53::ResourceRecordSet::Change;
@@ -63,7 +61,7 @@ has 'ua' => (
         my $self = shift;
         LWP::UserAgent->new(
             keep_alive            => 10,
-            requests_redirectable => [ qw(GET HEAD DELETE PUT) ],
+            requests_redirectable => [qw(GET HEAD DELETE PUT)],
         );
     },
 );
@@ -114,7 +112,7 @@ sub request {
     my $content = delete $options{Content};
     my $request = HTTP::Request->new(
         uc $method, $uri,
-        [ map {$_ => $options{$_}} keys %options ],
+        [map {$_ => $options{$_}} keys %options],
         $content ? $content : undef,
     );
     my $rc = $self->ua->request($request);
@@ -153,11 +151,13 @@ sub get_hosted_zones {
         my $resp = $self->request('get',
             'https://route53.amazonaws.com/2010-10-01/hostedzone?maxitems=100'
                 . $start_marker);
-        push @zones,
-            (
-            ref $resp->{HostedZones}{HostedZone} eq 'ARRAY'
-            ? @{ $resp->{HostedZones}{HostedZone} }
-            : $resp->{HostedZones}{HostedZone});
+        if ($resp->{HostedZones}) {
+            push @zones,
+                (
+                ref $resp->{HostedZones}{HostedZone} eq 'ARRAY'
+                ? @{ $resp->{HostedZones}{HostedZone} }
+                : $resp->{HostedZones}{HostedZone});
+        }
         last if $resp->{IsTruncated} eq 'false';
         $start_marker = '?marker=' . $resp->{NextMarker};
     }
@@ -208,7 +208,7 @@ sub batch_create {
         "Your batch is not an arrayref of Net::Amazon::Route53::ResourceRecordSets"
         if scalar(@invalid);
 
-    my $hostedzone_id = $batch->[ 0 ]->hostedzone->id;
+    my $hostedzone_id = $batch->[0]->hostedzone->id;
     my @wrong_zone = grep {$_->hostedzone->id ne $hostedzone_id} @$batch;
     die "Your batch contains records from different hosted zones"
         if scalar(@wrong_zone);
@@ -296,7 +296,7 @@ sub atomic_update {
             if scalar(@invalid);
     }
 
-    my $hostedzone_id = $original->[ 0 ]->hostedzone->id;
+    my $hostedzone_id = $original->[0]->hostedzone->id;
     my @wrong_zone =
         grep {$_->hostedzone->id ne $hostedzone_id} (@$original, @$new);
     die "A record set contains records from different hosted zones"
@@ -312,7 +312,8 @@ sub atomic_update {
     my @deletions =
         grep {!(defined $new{ $_->name . '-' . $_->type })} @$original;
     my %deleted = map {$_->name . '-' . $_->type => 1} @deletions;
-    my @changes = grep {defined $new{ $_->name . '-' . $_->type }}
+    my @changes =
+        grep {defined $new{ $_->name . '-' . $_->type }}
         grep {!(defined $deleted{ $_->name . '-' . $_->type })} @$original;
     my @change_objects = map {
         Net::Amazon::Route53::ResourceRecordSet::Change->new(
@@ -324,8 +325,7 @@ sub atomic_update {
             original_values => $_->values,
             values          => $new_records{ $_->name . '-' . $_->type }->values
             )
-        }
-        grep {
+        } grep {
         join(',', @{ $_->values }) ne
             join(',', @{ $new_records{ $_->name . '-' . $_->type }->values })
         } @changes;
@@ -333,10 +333,8 @@ sub atomic_update {
     my $batch_xml = $self->_batch_request_header;
 
     # Do not attempt to push an empty changeset
-    return Net::Amazon::Route53::Change->new(
-        route53 => $self,
-        status  => 'NOOP'
-    ) if @change_objects + @deletions + @creates < 1;
+    return Net::Amazon::Route53::Change->new(route53 => $self, status => 'NOOP')
+        if @change_objects + @deletions + @creates < 1;
 
     for my $rr (@change_objects) {
         $rr->name =~ /\.$/
@@ -410,7 +408,7 @@ sub batch_change {
         "Your batch is not an arrayref of Net::Amazon::Route53::ResourceRecordSet::Changes"
         if scalar(@invalid);
 
-    my $hostedzone_id = $batch->[ 0 ]->hostedzone->id;
+    my $hostedzone_id = $batch->[0]->hostedzone->id;
     my @wrong_zone = grep {$_->hostedzone->id ne $hostedzone_id} @$batch;
     die "Your batch contains records from different hosted zones"
         if scalar(@wrong_zone);
@@ -618,6 +616,9 @@ Marco FONTANI <mfontani@cpan.org>
 
 Daiji Hirata <hirata@uva.ne.jp>
 Amiri Barksdale <amiri@arisdottle.net>
+Chris Weyl <cweyl@alumni.drew.edu>
+Jason <jasonjayr+oss@gmail.com>
+Ulrich Kautz <ulrich.kautz@googlemail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
