@@ -2,10 +2,8 @@ use strict;
 use warnings;
 
 package Net::Amazon::Route53::Change;
-{
-  $Net::Amazon::Route53::Change::VERSION = '0.123250';
-}
-use Mouse;
+$Net::Amazon::Route53::Change::VERSION = '0.160530';
+use Any::Moose;
 use HTML::Entities;
 
 =head2 SYNOPSIS
@@ -26,7 +24,8 @@ to Amazon's Route 53 service
 
 =cut
 
-has 'route53' => (is => 'rw', isa => 'Net::Amazon::Route53', required => 1,);
+has 'route53' =>
+    (is => 'rw', isa => 'Net::Amazon::Route53', required => 1, weak_ref => 1);
 
 =head3 id
 
@@ -74,7 +73,7 @@ sub refresh {
     }
 }
 
-no Mouse;
+no Any::Moose;
 
 =head1 AUTHOR
 
