@@ -2,10 +2,8 @@ use strict;
 use warnings;
 
 package Net::Amazon::Route53::HostedZone;
-{
-  $Net::Amazon::Route53::HostedZone::VERSION = '0.123250';
-}
-use Mouse;
+$Net::Amazon::Route53::HostedZone::VERSION = '0.160530';
+use Any::Moose;
 use HTML::Entities;
 
 use Net::Amazon::Route53::Change;
@@ -29,7 +27,8 @@ to Amazon's Route 53 service
 
 =cut
 
-has 'route53' => (is => 'rw', isa => 'Net::Amazon::Route53', required => 1,);
+has 'route53' =>
+    (is => 'rw', isa => 'Net::Amazon::Route53', required => 1, weak_ref => 1);
 
 =head3 id
 
@@ -71,8 +70,7 @@ has 'nameservers' => (
         my $self = shift;
         my $resp = $self->route53->request('get',
             'https://route53.amazonaws.com/2010-10-01/' . $self->id);
-        my @nameservers =
-            map {decode_entities($_)}
+        my @nameservers = map {decode_entities($_)}
             @{ $resp->{DelegationSet}{NameServers}{NameServer} };
         \@nameservers;
     });
@@ -113,7 +111,7 @@ has 'resource_record_sets' => (
                             ref $res->{ResourceRecords}{ResourceRecord} eq
                                 'ARRAY'
                             ? $res->{ResourceRecords}{ResourceRecord}
-                            : [ $res->{ResourceRecords}{ResourceRecord} ] }
+                            : [$res->{ResourceRecords}{ResourceRecord}] }
                     ],
                     );
             }
@@ -159,8 +157,7 @@ ENDXML
         map {$_} $self->name,
         $self->callerreference, $self->comment);
     my $resp = $self->route53->request(
-        'post',
-        'https://route53.amazonaws.com/2010-10-01/hostedzone',
+        'post', 'https://route53.amazonaws.com/2010-10-01/hostedzone',
         'content-type' => 'text/xml; charset=UTF-8',
         Content        => $request_xml,
     );
@@ -219,7 +216,7 @@ sub delete {
     return $change;
 }
 
-no Mouse;
+no Any::Moose;
 
 =head1 AUTHOR
 
