@@ -2,10 +2,8 @@ use strict;
 use warnings;
 
 package Net::Amazon::Route53::ResourceRecordSet::Change;
-{
-  $Net::Amazon::Route53::ResourceRecordSet::Change::VERSION = '0.123250';
-}
-use Mouse;
+$Net::Amazon::Route53::ResourceRecordSet::Change::VERSION = '0.160530';
+use Any::Moose;
 extends "Net::Amazon::Route53::ResourceRecordSet";
 use HTML::Entities;
 
@@ -125,7 +123,7 @@ ENDXML
     return $change;
 }
 
-no Mouse;
+no Any::Moose;
 
 =head1 AUTHOR
 
